@@ -1,6 +1,6 @@
 #' Plot a \link{tabplot-object}
 #' 
-#' Plot a \link{tabplot-object}. The arguments of this function, which specify the layout, can also be passed on to \code{\link{tableplot}} directly. New in version 1.2 is the argument \code{numMode}, which determines how numeric variables are plot.
+#' Plot a \link{tabplot-object}. The arguments of this function, which specify the layout, can also be passed on to \code{\link{tableplot}} directly.
 #'
 #' @aliases plot.tabplot
 #' @name plot.tabplot
@@ -16,24 +16,14 @@
 #' @param showNumAxes plots an x-axis for each numerical variable, along with grid lines (\code{TRUE} by default).
 #' @param rotateNames logical or numeric value that determines the rotation angle of the column names. If \code{TRUE}, they are rotated 90 degrees. By default, column names are rotated when the number of columns is greater than 15.
 #' @param relative boolean that determines whether relative scales are used for relative tableplots. If \code{TRUE}, then \code{mean.diff.rel<-(mean2-mean1)/mean1*100} are used. If \code{FALSE}, then the absolute diference is taken: \code{mean <- mean2-mean}.
-#' @param numMode character value that determines how numeric values are plotted. The value consists of the following building blocks, which are concatenated with the "-" symbol. The default value is "mb-sdb-sdl". Prior to version 1.2, "MB-ML" was the default value.
-#' \describe{
-#' \item{\code{sdb}}{sd bars between mean-sd to mean+sd are shown}
-#' \item{\code{sdl}}{sd lines at mean-sd and mean+sd are shown}
-#' \item{\code{mb}}{mean bars are shown}
-#' \item{\code{MB}}{mean bars are shown, where the color of the bar indicate completeness where positive mean values are blue and negative orange}
-#' \item{\code{ml}}{mean lines are shown}
-#' \item{\code{ML}}{mean lines are shown, where positive mean values are blue and negative orange}
-#' \item{\code{mean2}}{mean values are shown}
-#' }
 #' @param vp \code{\link[grid:viewport]{viewport}} to draw plot in (for instance useful to stack multiple tableplots)
 #' @param ... other arguments are not used
-#' @example ../examples/plot_tabplot.R
+#' @example ./examples/plot_tabplot.R
 #' @export
 #' @import grid
 #' @method plot tabplot
 plot.tabplot <-
-function(x, fontsize = 10, legend.lines = 8, max_print_levels = 15, text_NA = "missing", title = NULL, showTitle = NULL, fontsize.title = 14, showNumAxes=TRUE, rotateNames = NA, relative=FALSE, numMode="mb-sdb-ml", vp=NULL, ...) {
+function(x, fontsize = 10, legend.lines = 8, max_print_levels = 15, text_NA = "missing", title = NULL, showTitle = NULL, fontsize.title = 14, showNumAxes=TRUE, rotateNames = NA, relative=FALSE, vp=NULL, ...) {
 
 	
 	if (!(class(x)[1] %in% c("tabplot", "tabplot_compare"))) stop(paste(deparse(substitute(x)), "is not a tabplot-object"))
@@ -41,9 +31,8 @@ function(x, fontsize = 10, legend.lines = 8, max_print_levels = 15, text_NA = "m
 	compare <- (class(x)=="tabplot_compare")
 	#relative <- relative && compare
 	
-	numMode <- strsplit(numMode, "-", fixed=TRUE)[[1]]
 	
-	if (compare && any(c("sdb", "sdl") %in% numMode)) message("Independence of the compared tableplots assumed for the calculation of the standard deviations.")
+	if (compare && any(c("sdb", "sdl") %in% x$numMode)) message("Independence of the compared tableplots assumed for the calculation of the standard deviations.")
 	
 	if (length(fontsize)!=1 || !is.numeric(fontsize)) stop("invalid fontsize")
 
@@ -193,7 +182,7 @@ function(x, fontsize = 10, legend.lines = 8, max_print_levels = 15, text_NA = "m
 				formats <- format(numbers, big.mark=",")
 				widths <- convertWidth(stringWidth(formats), "npc", valueOnly=TRUE)
 				width <- max(widths)
-				spacer <- 0.1 + convertWidth(stringWidth("\t"), "npc", valueOnly=TRUE)
+				spacer <- 0.1 + convertWidth(stringWidth("   "), "npc", valueOnly=TRUE)
 				xpos <- spacer + width
 				space.row_bins <- convertWidth(stringWidth("row bins:  "), "npc", valueOnly=TRUE)
 				grid.text("row bins:", x=0.1, y=unit(5.5, units="lines"), just="left")
@@ -254,7 +243,7 @@ function(x, fontsize = 10, legend.lines = 8, max_print_levels = 15, text_NA = "m
 				})
 			
 				if (tCol$isnumeric){
-					plotNumCol(tCol, x, vpTitle, vpGraph, vpLegend, showNumAxes, relative, numMode)
+					plotNumCol(tCol, x, vpTitle, vpGraph, vpLegend, showNumAxes, relative, x$numMode)
 				}
 				else {
 					plotCatCol(tCol, x, vpTitle, vpGraph, vpLegend, max_print_levels,
