@@ -1,8 +1,14 @@
-tableplot_checkCols <- function(sortCol, colNames) {	
+tableplot_checkCols <- function(sortCol, sortCol2, colNames) {	
 	if (!missing(sortCol)) {
 		nl <- as.list(seq_along(colNames))
 		names(nl) <- colNames
-		sortCol <- eval(sortCol, nl, parent.frame())
+		
+		sortCol <- tryCatch({
+			if (is.function(sortCol2)) {
+				eval(sortCol, nl, parent.frame())
+			} else sortCol2
+		}, error=function(e) eval(sortCol, nl, parent.frame()))
+		
 		if (is.character(sortCol)) sortCol <- which(sortCol==colNames)
 		if (!length(sortCol)) stop("Incorrect sortCol argument")
 	}
